@@ -60,9 +60,10 @@ iDeclareTypeConstructionArgs(GmCerts, const char *saveDir)
 
 typedef iBool (*iGmCertsIdentityFilterFunc)(void *context, const iGmIdentity *);
 
-iBool               checkTrust_GmCerts      (iGmCerts *, iRangecc domain, uint16_t port, const iTlsCertificate *cert);
-void                setTrusted_GmCerts      (iGmCerts *, iRangecc domain, uint16_t port, const iBlock *fingerprint,
-                                             const iDate *validUntil);
+iBool               checkTrust_GmCerts      (iGmCerts *, iRangecc domain, uint16_t port,
+                                             const iTlsCertificate *cert);
+void                setTrusted_GmCerts      (iGmCerts *, iRangecc domain, uint16_t port,
+                                             const iBlock *fingerprint, const iDate *validUntil);
 iTime               domainValidUntil_GmCerts(const iGmCerts *, iRangecc domain, uint16_t port);
 
 /**
@@ -81,7 +82,8 @@ iGmIdentity *       newIdentity_GmCerts     (iGmCerts *, int flags, iDate validU
                                              const iString *userId, const iString *domain,
                                              const iString *org, const iString *country);
 
-void                importIdentity_GmCerts  (iGmCerts *, iTlsCertificate *cert, const iString *notes); /* takes ownership */
+void                importIdentity_GmCerts  (iGmCerts *, iTlsCertificate *cert,
+                                             const iString *notes); /* takes ownership */
 void                deleteIdentity_GmCerts  (iGmCerts *, iGmIdentity *identity);
 void                saveIdentities_GmCerts  (const iGmCerts *);
 
