@@ -24,6 +24,10 @@ SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE. */
 
 #include "ui/util.h"
 
+iDeclareType(MenuItem)
+iDeclareType(Window)
+iDeclareType(Widget)
+
 /* Platform-specific functionality for macOS */
 
 iBool   shouldDefaultToMetalRenderer_MacOS  (void);
@@ -31,9 +35,12 @@ iBool   shouldDefaultToMetalRenderer_MacOS  (void);
 void    enableMomentumScroll_MacOS  (void);
 void    registerURLHandler_MacOS    (void);
 void    setupApplication_MacOS      (void);
+void    hideTitleBar_MacOS          (iWindow *window);
 void    insertMenuItems_MacOS       (const char *menuLabel, int atIndex, const iMenuItem *items, size_t count);
 void    removeMenu_MacOS            (int atIndex);
 void    enableMenu_MacOS            (const char *menuLabel, iBool enable);
 void    enableMenuItem_MacOS        (const char *menuItemCommand, iBool enable);
 void    enableMenuItemsByKey_MacOS  (int key, int kmods, iBool enable);
 void    handleCommand_MacOS         (const char *cmd);
+
+void    showPopupMenu_MacOS         (iWidget *source, iInt2 windowCoord, const iMenuItem *items, size_t n);
