@@ -27,7 +27,7 @@ SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE. */
 #include "command.h"
 #include "defs.h"
 #include "documentwidget.h"
-#include "embedded.h"
+#include "resources.h"
 #include "inputwidget.h"
 #include "keys.h"
 #include "labelwidget.h"
@@ -78,6 +78,9 @@ static const iMenuItem navMenuItems_[] = {
     { gear_Icon " ${menu.preferences}", SDLK_COMMA, KMOD_PRIMARY, "preferences" },
     { "${menu.help}", SDLK_F1, 0, "!open url:about:help" },
     { "${menu.releasenotes}", 0, 0, "!open url:about:version" },
+ #if defined (LAGRANGE_ENABLE_WINSPARKLE)
+    { "${menu.update}", 0, 0, "updater.check" },
+ #endif
     { "---" },
     { "${menu.quit}", 'q', KMOD_PRIMARY, "quit" }
 };
@@ -139,11 +142,11 @@ static const iMenuItem identityButtonMenuItems_[] = {
     { add_Icon " ${menu.identity.new}", newIdentity_KeyShortcut, "ident.new" },
     { "${menu.identity.import}", SDLK_i, KMOD_PRIMARY | KMOD_SHIFT, "ident.import" },
     { "---" },
-    { person_Icon " ${menu.show.identities}", '4', KMOD_PRIMARY, "sidebar.mode arg:3 show:1" },
+    { person_Icon " ${menu.show.identities}", '4', KMOD_PRIMARY, "sidebar.mode arg:3 toggle:1" },
 # else
     { add_Icon " ${menu.identity.new}", 0, 0, "ident.new" },
     { "---" },
-    { person_Icon " ${menu.show.identities}", 0, 0, "sidebar.mode arg:3 show:1" },
+    { person_Icon " ${menu.show.identities}", 0, 0, "sidebar.mode arg:3 toggle:1" },
 # endif
 };
 #endif
@@ -623,6 +626,7 @@ static void updateNavBarSize_(iWidget *navBar) {
     /* Button sizing. */
     if (isNarrow ^ ((flags_Widget(navBar) & tight_WidgetFlag) != 0)) {
         setFlags_Widget(navBar, tight_WidgetFlag, isNarrow);
+        showCollapsed_Widget(findChild_Widget(navBar, "navbar.sidebar"), !isNarrow);
         iObjectList *lists[] = {
             children_Widget(navBar),
             children_Widget(findChild_Widget(navBar, "url")),
@@ -631,10 +635,12 @@ static void updateNavBarSize_(iWidget *navBar) {
         iForIndices(k, lists) {
             iForEach(ObjectList, i, lists[k]) {
                 iWidget *child = as_Widget(i.object);
-                setFlags_Widget(child, tight_WidgetFlag, isNarrow);
-                if (isInstance_Object(i.object, &Class_LabelWidget)) {
-                    iLabelWidget *label = i.object;
-                    updateSize_LabelWidget(label);
+                if (cmp_String(id_Widget(i.object), "navbar.unsplit")) {
+                    setFlags_Widget(child, tight_WidgetFlag, isNarrow);
+                    if (isInstance_Object(i.object, &Class_LabelWidget)) {
+                        iLabelWidget *label = i.object;
+                        updateSize_LabelWidget(label);
+                    }
                 }
             }
         }
@@ -757,9 +763,17 @@ static iBool handleNavBarCommands_(iWidget *navBar, const char *cmd) {
             if (equal_Command(cmd, "document.changed")) {
                 iInputWidget *url = findWidget_Root("url");
                 const iString *urlStr = collect_String(suffix_Command(cmd, "url"));
+                const enum iGmStatusCode statusCode = argLabel_Command(cmd, "status");
                 trimCache_App();
                 trimMemory_App();
-                visitUrl_Visited(visited_App(), urlStr, 0);
+                visitUrl_Visited(visited_App(),
+                                 urlStr,
+                                 /* The transient flag modifies history navigation behavior on
+                                    special responses like input queries. */
+                                 category_GmStatusCode(statusCode) == categoryInput_GmStatusCode ||
+                                 category_GmStatusCode(statusCode) == categoryRedirect_GmStatusCode
+                                     ? transient_VisitedUrlFlag
+                                     : 0);
                 postCommand_App("visited.changed"); /* sidebar will update */
                 setText_InputWidget(url, urlStr);
                 checkLoadAnimation_Root_(get_Root());
@@ -1011,6 +1025,16 @@ void updateMetrics_Root(iRoot *d) {
     postRefresh_App();
 }
 
+static void addUnsplitButton_(iWidget *navBar) {
+    iLabelWidget *unsplit = addChildFlags_Widget(
+        navBar,
+        iClob(newIcon_LabelWidget(close_Icon, 0, 0, "ui.split arg:0 focusother:1")),
+        collapse_WidgetFlag | frameless_WidgetFlag | tight_WidgetFlag | hidden_WidgetFlag);
+    setId_Widget(as_Widget(unsplit), "navbar.unsplit");
+    setTextColor_LabelWidget(unsplit, uiTextAction_ColorId);
+    updateSize_LabelWidget(unsplit);
+}
+
 void createUserInterface_Root(iRoot *d) {
     iWidget *root = d->widget = new_Widget();
     root->rect.size = get_Window()->size;
@@ -1089,22 +1113,19 @@ void createUserInterface_Root(iRoot *d) {
         addChild_Widget(div, iClob(navBar));
         setBackgroundColor_Widget(navBar, uiBackground_ColorId);
         setCommandHandler_Widget(navBar, handleNavBarCommands_);
+#if defined (iPlatformApple)
+        addUnsplitButton_(navBar);
+#endif
         iWidget *navBack;
         setId_Widget(navBack = addChildFlags_Widget(navBar, iClob(newIcon_LabelWidget(backArrow_Icon, 0, 0, "navigate.back")), collapse_WidgetFlag), "navbar.back");
         setId_Widget(addChildFlags_Widget(navBar, iClob(newIcon_LabelWidget(forwardArrow_Icon, 0, 0, "navigate.forward")), collapse_WidgetFlag), "navbar.forward");
-        /* Mobile devices have a button for easier access to the left sidebar. */
-        if (deviceType_App() != desktop_AppDeviceType) {
-            setId_Widget(addChildFlags_Widget(
-                             navBar,
-                             iClob(newIcon_LabelWidget(leftHalf_Icon, 0, 0, "sidebar.toggle")),
-                             collapse_WidgetFlag),
-                         "navbar.sidebar");
-        }
+        /* Button for toggling the left sidebar. */
+        setId_Widget(addChildFlags_Widget(
+                         navBar,
+                         iClob(newIcon_LabelWidget(leftHalf_Icon, 0, 0, "sidebar.toggle")),
+                         collapse_WidgetFlag),
+                     "navbar.sidebar");
         addChildFlags_Widget(navBar, iClob(new_Widget()), expand_WidgetFlag);
-        iLabelWidget *idMenu = makeMenuButton_LabelWidget(
-            "\U0001f464", identityButtonMenuItems_, iElemCount(identityButtonMenuItems_));
-        setAlignVisually_LabelWidget(idMenu, iTrue);
-        setId_Widget(addChildFlags_Widget(navBar, iClob(idMenu), collapse_WidgetFlag), "navbar.ident");
         iInputWidget *url;
         /* URL input field. */ {
             url = new_InputWidget(0);
@@ -1246,10 +1267,11 @@ void createUserInterface_Root(iRoot *d) {
             arrange_Widget(urlButtons);
             setId_Widget(addChild_Widget(rightEmbed, iClob(makePadding_Widget(0))), "url.embedpad");
         }
-        if (deviceType_App() != desktop_AppDeviceType) {
-            /* On mobile, the Identities button is on the right side of the URL bar. */
-            iWidget *ident = removeChild_Widget(navBar, findChild_Widget(navBar, "navbar.ident"));
-            addChild_Widget(navBar, iClob(ident));
+        /* The active identity menu. */ {
+            iLabelWidget *idMenu = makeMenuButton_LabelWidget(
+                "\U0001f464", identityButtonMenuItems_, iElemCount(identityButtonMenuItems_));
+            setAlignVisually_LabelWidget(idMenu, iTrue);
+            setId_Widget(addChildFlags_Widget(navBar, iClob(idMenu), collapse_WidgetFlag), "navbar.ident");
         }
         addChildFlags_Widget(navBar, iClob(new_Widget()), expand_WidgetFlag);
         setId_Widget(addChildFlags_Widget(navBar,
@@ -1271,6 +1293,10 @@ void createUserInterface_Root(iRoot *d) {
 #   endif
         setAlignVisually_LabelWidget(navMenu, iTrue);
         setId_Widget(addChildFlags_Widget(navBar, iClob(navMenu), collapse_WidgetFlag), "navbar.menu");
+#endif
+#if !defined (iPlatformApple)
+        /* On PC platforms, the close buttons are generally on the top right. */
+        addUnsplitButton_(navBar);
 #endif
     }
     /* Tab bar. */ {
