@@ -54,7 +54,8 @@ struct Impl_ScrollWidget {
 };
 
 static void updateMetrics_ScrollWidget_(iScrollWidget *d) {
-    as_Widget(d)->rect.size.x = gap_UI * 3;
+    iWidget *w = as_Widget(d);
+    w->rect.size.x = gap_UI * 3;
 }
 
 static void animateOpacity_ScrollWidget_(void *ptr) {
@@ -89,8 +90,22 @@ static int thumbSize_ScrollWidget_(const iScrollWidget *d) {
     return iMax(gap_UI * 6, d->thumbSize);
 }
 
+static iRect bounds_ScrollWidget_(const iScrollWidget *d) {
+    const iWidget *w = constAs_Widget(d);
+    iRect bounds = bounds_Widget(w);
+    if (deviceType_App() == phone_AppDeviceType && isPortrait_App()) {
+        /* Account for the hidable toolbar. */
+        int toolbarHeight = lineHeight_Text(uiLabelLarge_FontId) + 3 * gap_UI;
+        int excess = bottom_Rect(bounds) - (bottom_Rect(safeRect_Root(w->root)) - toolbarHeight);
+        if (excess > 0) {
+            adjustEdges_Rect(&bounds, 0, 0, -excess, 0);
+        }
+    }
+    return bounds;
+}
+
 static iRect thumbRect_ScrollWidget_(const iScrollWidget *d) {
-    const iRect bounds = bounds_Widget(constAs_Widget(d));
+    const iRect bounds = bounds_ScrollWidget_(d);
     iRect rect = init_Rect(bounds.pos.x, bounds.pos.y, bounds.size.x, 0);
     const int total = size_Range(&d->range);
     if (total > 0) {
@@ -108,7 +123,7 @@ static void unfade_ScrollWidget_(iScrollWidget *d, float opacity) {
     d->fadeStart = SDL_GetTicks() + 1000;
     if (targetValue_Anim(&d->opacity) < opacity) {
         setValue_Anim(&d->opacity, opacity, 66);
-        addTicker_App(animateOpacity_ScrollWidget_, d);
+        addTickerRoot_App(animateOpacity_ScrollWidget_, as_Widget(d)->root, d);
     }
     if (!d->willCheckFade && d->fadeEnabled) {
         d->willCheckFade = iTrue;
@@ -180,7 +195,7 @@ static iBool processEvent_ScrollWidget_(iScrollWidget *d, const SDL_Event *ev) {
             refresh_Widget(w);
             return iTrue;
         case drag_ClickResult: {
-            const iRect bounds = bounds_Widget(w);
+            const iRect bounds = bounds_ScrollWidget_(d);
             const int offset = delta_Click(&d->click).y;
             const int total = size_Range(&d->range);
             int dpos = (float) offset / (float) (height_Rect(bounds) - thumbSize_ScrollWidget_(d)) * total;
@@ -217,7 +232,7 @@ static iBool processEvent_ScrollWidget_(iScrollWidget *d, const SDL_Event *ev) {
 
 static void draw_ScrollWidget_(const iScrollWidget *d) {
     const iWidget *w         = constAs_Widget(d);
-    const iRect    bounds    = bounds_Widget(w);
+    const iRect    bounds    = bounds_ScrollWidget_(d);
     const iBool    isPressed = (flags_Widget(w) & pressed_WidgetFlag) != 0;
     if (bounds.size.x > 0) {
         iPaint p;
